==> tick-0.4.0-1.21.4-sources.jar: io/github/dennisochulor/tickrate/mixin/client/tick/WorldMixin.java <==
package io.github.dennisochulor.tickrate.mixin.client.tick;

import io.github.dennisochulor.tickrate.TickRateClientManager;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.Redirect;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.function.Consumer;
import net.minecraft.class_1297;
import net.minecraft.class_1923;
import net.minecraft.class_1937;
import net.minecraft.class_310;
import net.minecraft.class_5562;
import net.minecraft.class_9779;

@Mixin(class_1937.class)
public abstract class WorldMixin {

    @Shadow public abstract boolean isClient();

    @Inject(method = "tickEntity", at = @At("HEAD"), cancellable = true)
    public <T extends class_1297> void tickEntity(Consumer<T> tickConsumer, T entity, CallbackInfo ci) {
        if(isClient() && TickRateClientManager.serverHasMod()) {
            class_9779 renderTickCounter = class_310.method_1551().method_61966();
            if(renderTickCounter.tickRate$getMovingI() >= TickRateClientManager.getEntityTickDelta(entity).i()) {
                ci.cancel();
            }
        }
    }

    @Redirect(method = "tickBlockEntities", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/chunk/BlockEntityTickInvoker;tick()V"))
    protected void tickBlockEntities(class_5562 instance) {
        if(isClient() && TickRateClientManager.serverHasMod()) {
            class_9779 renderTickCounter = class_310.method_1551().method_61966();
            if(renderTickCounter.tickRate$getMovingI() < TickRateClientManager.getChunkTickDelta(class_1923.method_37232(instance.method_31705())).i()) {
                instance.method_31703();
            }
        }
        else instance.method_31703();
    }

}

==> tick-0.6.0-1.21.1-sources.jar: io/github/dennisochulor/tickrate/mixin/client/tick/WorldMixin.java <==
package io.github.dennisochulor.tickrate.mixin.client.tick;

import io.github.dennisochulor.tickrate.TickRateClientManager;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.Redirect;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.function.Consumer;
import net.minecraft.class_1297;
import net.minecraft.class_1923;
import net.minecraft.class_1937;
import net.minecraft.class_310;
import net.minecraft.class_5562;
import net.minecraft.class_9779;

@Mixin(class_1937.class)
public abstract class WorldMixin {

    @Shadow public abstract boolean isClient();

    @Inject(method = "tickEntity", at = @At("HEAD"), cancellable = true)
    public <T extends class_1297> void tickEntity(Consumer<T> tickConsumer, T entity, CallbackInfo ci) {
        if(isClient() && TickRateClientManager.serverHasMod()) {
            class_9779 renderTickCounter = class_310.method_1551().method_60646();
            if(renderTickCounter.tickRate$getMovingI() >= TickRateClientManager.getEntityTickDelta(entity).i()) {
                ci.cancel();
            }
        }
    }

    @Redirect(method = "tickBlockEntities", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/chunk/BlockEntityTickInvoker;tick()V"))
    protected void tickBlockEntities(class_5562 instance) {
        if(isClient() && TickRateClientManager.serverHasMod()) {
            class_9779 renderTickCounter = class_310.method_1551().method_60646();
            if(renderTickCounter.tickRate$getMovingI() < TickRateClientManager.getChunkTickDelta(new class_1923(instance.method_31705())).i()) {
                instance.method_31703();
            }
        }
        else instance.method_31703();
    }

}
